<?xml version="1.0" encoding="ISO-8859-1" ?>
<!--
   This transforms a master specs XML file into an ActionGroup XML
   file which CUI may then input and process.
-->
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
      version="1.0">
<!--
-->
   <xsl:output method="xml" indent="yes" />
   <xsl:strip-space elements="//SpecFileName" />

   <!--
      Starting point for the transform.
   -->
   <xsl:template match="/">
      <xsl:element name="ActionGroup">
         <xsl:attribute name="baseDirectory"><xsl:value-of select="//BaseDirectory/@directory" /></xsl:attribute>
         <group label="Process Input">
            <xsl:apply-templates
               select="//InputMeasurementChannels" />
         </group>
         <group label="Process Output">
            <xsl:apply-templates select="//AnalogOutputChannels" />
            <xsl:apply-templates select="//DigitalOutputChannels" />
            <xsl:apply-templates select="//CounterOutputChannels" />
         </group>
         <group label="Standard Services">
            <xsl:apply-templates select="//GeneralPurposeChannels" />
            <xsl:apply-templates select="//LimitChannels" />
            <xsl:apply-templates select="//ControlChannels" />
            <xsl:apply-templates select="//PAMSpecs" />
            <xsl:apply-templates select="//ASAM3Specs" />
         </group>
      </xsl:element>
   </xsl:template>

   <!--
      Transform inpt_specs group.
   -->
   <xsl:template match="//InputMeasurementChannels">
      <group label="Input Measurement Channels">
         <xsl:attribute name="classname">com.cybermetrix.cyflex.specfiles.inpt_specs</xsl:attribute>
         <xsl:element name="launchItem">
            <xsl:attribute name="label">Create inpt specs file</xsl:attribute>
            <xsl:attribute name="tooltip">Create new input specs file from scratch.</xsl:attribute>
            <xsl:attribute name="repeatable">true</xsl:attribute>
            <xsl:attribute name="command">specfilegui inpt_specs</xsl:attribute>
         </xsl:element>
         inpt_specs.def;
         <xsl:apply-templates
               select="//InputMeasurementChannels/SpecFileName" />
      </group>
   </xsl:template>

   <!--
      Transform inpt_specs file.
   -->
   <xsl:template match="//InputMeasurementChannels/SpecFileName">
      <xsl:element name="launchItem">
         <xsl:attribute name="tooltip">Edit input specs file <xsl:value-of select="@file" /></xsl:attribute>
         <xsl:attribute name="repeatable">false</xsl:attribute>
         <xsl:attribute name="command">specfilegui inpt_specs <xsl:value-of select="@file" /></xsl:attribute>
         <xsl:value-of select="@file" />
      </xsl:element>
   </xsl:template>

   <!--
      Transform ao_specs group.
   -->
   <xsl:template match="//AnalogOutputChannels">
      <group label="Analog Output Channels">
         <xsl:attribute name="classname">com.cybermetrix.cyflex.specfiles.ao_specs</xsl:attribute>
         <xsl:element name="launchItem">
            <xsl:attribute name="label">Create ao specs file</xsl:attribute>
            <xsl:attribute name="tooltip">Create new analog output specs file from scratch.</xsl:attribute>
            <xsl:attribute name="repeatable">true</xsl:attribute>
            <xsl:attribute name="command">specfilegui ao_specs</xsl:attribute>
         </xsl:element>
         ao_specs.def;
         <xsl:apply-templates
               select="//AnalogOutputChannels/SpecFileName" />
      </group>
   </xsl:template>

   <!--
      Transform ao_specs file.
   -->
   <xsl:template match="//AnalogOutputChannels/SpecFileName">
      <xsl:element name="launchItem">
         <xsl:attribute name="tooltip">Edit analog output specs file <xsl:value-of select="@file" /></xsl:attribute>
         <xsl:attribute name="repeatable">false</xsl:attribute>
         <xsl:attribute name="command">specfilegui ao_specs <xsl:value-of select="@file" /></xsl:attribute>
         <xsl:value-of select="@file" />
      </xsl:element>
   </xsl:template>

   <!--
      Transform do_specs group.
   -->
   <xsl:template match="//DigitalOutputChannels">
      <group label="Digital Output Channels">
         <xsl:attribute name="classname">com.cybermetrix.cyflex.specfiles.do_specs</xsl:attribute>
         <xsl:element name="launchItem">
            <xsl:attribute name="label">Create do specs file</xsl:attribute>
            <xsl:attribute name="tooltip">Create new digital output specs file from scratch.</xsl:attribute>
            <xsl:attribute name="repeatable">true</xsl:attribute>
            <xsl:attribute name="command">specfilegui do_specs</xsl:attribute>
         </xsl:element>
         do_specs.def;
         <xsl:apply-templates
               select="//DigitalOutputChannels/SpecFileName" />
      </group>
   </xsl:template>

   <!--
      Transform do_specs file.
   -->
   <xsl:template match="//DigitalOutputChannels/SpecFileName">
      <xsl:element name="launchItem">
         <xsl:attribute name="tooltip">Edit digital output specs file <xsl:value-of select="@file" /></xsl:attribute>
         <xsl:attribute name="repeatable">false</xsl:attribute>
         <xsl:attribute name="command">specfilegui do_specs <xsl:value-of select="@file" /></xsl:attribute>
         <xsl:value-of select="@file" />
      </xsl:element>
   </xsl:template>

   <!--
      Transform co_specs group.
   -->
   <xsl:template match="//CounterOutputChannels">
      <group label="Counter Output Channels">
         <xsl:attribute name="classname">com.cybermetrix.cyflex.specfiles.co_specs</xsl:attribute>
         <xsl:element name="launchItem">
            <xsl:attribute name="label">Create co specs file</xsl:attribute>
            <xsl:attribute name="tooltip">Create new counter output specs file from scratch.</xsl:attribute>
            <xsl:attribute name="repeatable">true</xsl:attribute>
            <xsl:attribute name="command">specfilegui co_specs</xsl:attribute>
         </xsl:element>
         co_specs.def;
         <xsl:apply-templates
               select="//CounterOutputChannels/SpecFileName" />
      </group>
   </xsl:template>

   <!--
      Transform co_specs file.
   -->
   <xsl:template match="//CounterOutputChannels/SpecFileName">
      <xsl:element name="launchItem">
         <xsl:attribute name="tooltip">Edit counter output specs file <xsl:value-of select="@file" /></xsl:attribute>
         <xsl:attribute name="repeatable">false</xsl:attribute>
         <xsl:attribute name="command">specfilegui co_specs <xsl:value-of select="@file" /></xsl:attribute>
         <xsl:value-of select="@file" />
      </xsl:element>
   </xsl:template>

   <!--
      Transform gen_labels group.
   -->
   <xsl:template match="//GeneralPurposeChannels">
      <group label="General Purpose Channels">
         <xsl:attribute name="classname">com.cybermetrix.cyflex.specfiles.gen_labels</xsl:attribute>
         <xsl:element name="launchItem">
            <xsl:attribute name="label">Create gen_labels file</xsl:attribute>
            <xsl:attribute name="tooltip">Create new gen_labels specs file from scratch.</xsl:attribute>
            <xsl:attribute name="repeatable">true</xsl:attribute>
            <xsl:attribute name="command">specfilegui gen_labels</xsl:attribute>
         </xsl:element>
         gen_labels.def;
         <xsl:apply-templates
               select="//GeneralPurposeChannels/SpecFileName" />
      </group>
   </xsl:template>

   <!--
      Transform gen_labels file.
   -->
   <xsl:template match="//GeneralPurposeChannels/SpecFileName">
      <xsl:element name="launchItem">
         <xsl:attribute name="tooltip">Edit gen_labels specs file <xsl:value-of select="@file" /></xsl:attribute>
         <xsl:attribute name="repeatable">false</xsl:attribute>
         <xsl:attribute name="command">specfilegui gen_labels <xsl:value-of select="@file" /></xsl:attribute>
         <xsl:value-of select="@file" />
      </xsl:element>
   </xsl:template>

   <!--
      Transform limit_specs group.
   -->
   <xsl:template match="//LimitChannels">
      <group label="Limits on Channels">
         <xsl:attribute name="classname">com.cybermetrix.cyflex.specfiles.limit_specs</xsl:attribute>
         <xsl:element name="launchItem">
            <xsl:attribute name="label">Create limit specs file</xsl:attribute>
            <xsl:attribute name="tooltip">Create new limit specs file from scratch.</xsl:attribute>
            <xsl:attribute name="repeatable">true</xsl:attribute>
            <xsl:attribute name="command">specfilegui limit_specs</xsl:attribute>
         </xsl:element>
         limit_specs.def;
         <xsl:apply-templates select="//LimitChannels/SpecFileName" />
      </group>
   </xsl:template>

   <!--
      Transform limit_specs file.
   -->
   <xsl:template match="//LimitChannels/SpecFileName">
      <xsl:element name="launchItem">
         <xsl:attribute name="tooltip">Edit limit specs file <xsl:value-of select="@file" /></xsl:attribute>
         <xsl:attribute name="repeatable">false</xsl:attribute>
         <xsl:attribute name="command">specfilegui limit_specs <xsl:value-of select="@file" /></xsl:attribute>
         <xsl:value-of select="@file" />
      </xsl:element>
   </xsl:template>

   <!--
      Transform ctrl_specs group.
   -->
   <xsl:template match="//ControlChannels">
      <group label="Control Loops">
         <xsl:attribute name="classname">com.cybermetrix.cyflex.applications.ctrl_specs</xsl:attribute>
         <xsl:element name="launchItem">
            <xsl:attribute name="label">Create ctrl specs file</xsl:attribute>
            <xsl:attribute name="tooltip">Create new control loop specs file from scratch.</xsl:attribute>
            <xsl:attribute name="repeatable">true</xsl:attribute>
            <xsl:attribute name="command">specfilegui ctrl_specs</xsl:attribute>
         </xsl:element>
         ctrl_specs.def;
         <xsl:apply-templates
               select="//ControlChannels/SpecFileName" />
      </group>
   </xsl:template>

   <!--
      Transform ctlr_specs file.
   -->
   <xsl:template match="//ControlChannels/SpecFileName">
      <xsl:element name="launchItem">
         <xsl:attribute name="tooltip">Edit control loop specs file <xsl:value-of select="@file" /></xsl:attribute>
         <xsl:attribute name="repeatable">false</xsl:attribute>
         <xsl:attribute name="command">specfilegui ctrl_specs <xsl:value-of select="@file" /></xsl:attribute>
         <xsl:value-of select="@file" />
      </xsl:element>
   </xsl:template>

   <!--
      Transform pam_specs group.
   -->
   <xsl:template match="//PAMSpecs">
      <group label="PAM Specs">
         <xsl:attribute name="classname">com.cybermetrix.cyflex.specfiles.pam_specs</xsl:attribute>
         <xsl:element name="launchItem">
            <xsl:attribute name="label">Create PAM specs file</xsl:attribute>
            <xsl:attribute name="tooltip">Create new PAM specs file from scratch.</xsl:attribute>
            <xsl:attribute name="repeatable">true</xsl:attribute>
            <xsl:attribute name="command">specfilegui pam_specs</xsl:attribute>
         </xsl:element>
         pam_specs.def;
         <xsl:apply-templates select="//PAMSpecs/SpecFileName" />
      </group>
   </xsl:template>

   <!--
      Transform pam_specs file.
   -->
   <xsl:template match="//PAMSpecs/SpecFileName">
      <xsl:element name="launchItem">
         <xsl:attribute name="tooltip">Edit PAM specs file <xsl:value-of select="@file" /></xsl:attribute>
         <xsl:attribute name="repeatable">false</xsl:attribute>
         <xsl:attribute name="command">specfilegui pam_specs <xsl:value-of select="@file" /></xsl:attribute>
         <xsl:value-of select="@file" />
      </xsl:element>
   </xsl:template>

   <!--
      Transform ASAM3 group.
   -->
   <xsl:template match="//ASAM3Specs">
      <group label="ASAM3 Specs">
         <xsl:attribute name="classname">com.cybermetrix.cyflex.applications.asam3_specs</xsl:attribute>
         <xsl:element name="launchItem">
            <xsl:attribute name="label">Create ASAM3 specs file</xsl:attribute>
            <xsl:attribute name="tooltip">Create new ASAM3 specs file from scratch.</xsl:attribute>
            <xsl:attribute name="repeatable">true</xsl:attribute>
            <xsl:attribute name="command">specfilegui asam3_specs</xsl:attribute>
         </xsl:element>
         asam3_specs.def;
         <xsl:apply-templates select="//ASAM3Specs/SpecFileName" />
      </group>
   </xsl:template>

   <!--
      Transform asam3_specs file.
   -->
   <xsl:template match="//ASAM3Specs/SpecFileName">
      <xsl:element name="launchItem">
         <xsl:attribute name="tooltip">Edit ASAM3 specs file <xsl:value-of select="@file" /></xsl:attribute>
         <xsl:attribute name="repeatable">false</xsl:attribute>
         <xsl:attribute name="command">specfilegui asam3_specs <xsl:value-of select="@file" /></xsl:attribute>
         <xsl:value-of select="@file" />
      </xsl:element>
   </xsl:template>

   <xsl:template match="//BaseDirectory">
   </xsl:template>

</xsl:stylesheet>
